==> sife-0.0.7.tgz: package/lib/loadConfig.js <==
var fs = require('fs'),
	_ = require('underscore'),
	pathVariables,
	path = require('path');


function initPathVariables(conf) {
	pathVariables = {
		$components: conf.sources.components,
		$base: conf.sources.base,
		$themes: conf.sources.themes
	};
}

function replacePathVariables(obj) {
	_.each(obj, function(val, key) {
		if (typeof val === 'string') {
			_.each(pathVariables, function(varValue, varKey) {
				obj[key] = obj[key].replace(varKey, varValue);
			});
		} else if (typeof val === 'object') { // object & arrays
			replacePathVariables(val);
		}
	});
}


function fixPaths(obj, props, pathToSifeJson) {
	var sifeJsonDir = path.parse(pathToSifeJson).dir;
	sifeJsonDir = sifeJsonDir==='.' ? '' : sifeJsonDir+'/';
	_.each(props, function(prop) {
		if(obj[prop]){
			if (obj[prop].slice(-1) === '/') {
				obj[prop] = obj[prop].slice(0, -1);
			}
			obj[prop] = sifeJsonDir + obj[prop];
		}
	});
}

function processConfig(conf, pathToSifeJson){
	// make sure no folder path end with /
	fixPaths(conf.sources, ['base','components','themes', 'handlebars_helpers'], pathToSifeJson);
	fixPaths(conf.output.css, ['base','components','themes'], pathToSifeJson);
	fixPaths(conf.output, ['jst','js'], pathToSifeJson);


	// replace all $vars in paths
	initPathVariables(conf);
	replacePathVariables(conf);
}

module.exports = function(pathToSifeJson){
	var sifeJson,sifeConfig;

	pathToSifeJson = pathToSifeJson || './Sife.json';

	try{
		sifeJson = fs.readFileSync(pathToSifeJson);
	}catch(err){
		console.log('Error: Sife.json not found 😱');
		process.exit();
	}

	try{
		sifeConfig = JSON.parse(sifeJson);
	}catch(err){
		console.log('Error: Sife.json is not valid JSON 😵');
		process.exit();
	}

	processConfig(sifeConfig, pathToSifeJson);

	return sifeConfig;
};

if(process.env.NODE_ENV === 'test'){
	module.exports._private = {
		initPathVariables: initPathVariables,
		replacePathVariables: replacePathVariables,
		fixPaths: fixPaths
	};
}

==> sife-0.0.44.tgz: package/lib/loadConfig.js <==
var fs = require('fs'),
	_ = require('underscore'),
	pathVariables,
	path = require('path');


function initPathVariables(conf) {
	pathVariables = {
		$components: conf.sources.components,
		$base: conf.sources.base,
		$themes: conf.sources.themes
	};
}

function replacePathVariables(obj) {
	_.each(obj, function(val, key) {
		if (typeof val === 'string') {
			_.each(pathVariables, function(varValue, varKey) {
				obj[key] = obj[key].replace(varKey, varValue);
			});
		} else if (typeof val === 'object') { // object & arrays
			replacePathVariables(val);
		}
	});
}


function fixPaths(obj, props, pathToSifeJson) {
	var sifeJsonDir = path.parse(pathToSifeJson).dir;
	sifeJsonDir = sifeJsonDir==='.' ? '' : sifeJsonDir+'/';
	_.each(props, function(prop) {
		if(obj[prop]){
			if (obj[prop].slice(-1) === '/') {
				obj[prop] = obj[prop].slice(0, -1);
			}
			obj[prop] = sifeJsonDir + obj[prop];
		}
	});
}

function processConfig(conf, pathToSifeJson){
	// make sure no folder path end with /
	fixPaths(conf.sources, ['base','components','themes', 'handlebars_helpers', 'transpiler_task'], pathToSifeJson);
	fixPaths(conf.output.css, ['base','components','themes'], pathToSifeJson);
	fixPaths(conf.output, ['jst','js'], pathToSifeJson);


	// replace all $vars in paths
	initPathVariables(conf);
	replacePathVariables(conf);
}

module.exports = function(pathToSifeJson){
	var sifeJson,sifeConfig;

	pathToSifeJson = pathToSifeJson || './Sife.json';

	try{
		sifeJson = fs.readFileSync(pathToSifeJson);
	}catch(err){
		console.log('Error: Sife.json not found 😱');
		process.exit();
	}

	try{
		sifeConfig = JSON.parse(sifeJson);
	}catch(err){
		console.log('Error: Sife.json is not valid JSON 😵');
		process.exit();
	}

	processConfig(sifeConfig, pathToSifeJson);

	return sifeConfig;
};

if(process.env.NODE_ENV === 'test'){
	module.exports._private = {
		initPathVariables: initPathVariables,
		replacePathVariables: replacePathVariables,
		fixPaths: fixPaths
	};
}
